Class: Google::Cloud::Eventarc::V1::GoogleApiSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/eventarc/v1/google_api_source.rb

Overview

A GoogleApiSource represents a subscription of 1P events from a MessageBus.

Defined Under Namespace

Classes: AnnotationsEntry, LabelsEntry, OrganizationSubscription, ProjectSubscriptions

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Optional. Resource annotations.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Resource annotations.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The creation time.

Returns:



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#crypto_key_name::String

Returns Optional. Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt their event data.

It must match the pattern projects/*/locations/*/keyRings/*/cryptoKeys/*.

Returns:

  • (::String)

    Optional. Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt their event data.

    It must match the pattern projects/*/locations/*/keyRings/*/cryptoKeys/*.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#destination::String

Returns Required. Destination is the message bus that the GoogleApiSource is delivering to. It must be point to the full resource name of a MessageBus. Format: "projects/{PROJECT_ID}/locations/{region}/messagesBuses/{MESSAGE_BUS_ID).

Returns:

  • (::String)

    Required. Destination is the message bus that the GoogleApiSource is delivering to. It must be point to the full resource name of a MessageBus. Format: "projects/{PROJECT_ID}/locations/{region}/messagesBuses/{MESSAGE_BUS_ID)



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Optional. Resource display name.

Returns:

  • (::String)

    Optional. Resource display name.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#etag::String (readonly)

Returns Output only. This checksum is computed by the server based on the value of other fields, and might be sent only on update and delete requests to ensure that the client has an up-to-date value before proceeding.

Returns:

  • (::String)

    Output only. This checksum is computed by the server based on the value of other fields, and might be sent only on update and delete requests to ensure that the client has an up-to-date value before proceeding.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Resource labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Resource labels.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#logging_config::Google::Cloud::Eventarc::V1::LoggingConfig

Returns Optional. Config to control Platform logging for the GoogleApiSource.

Returns:



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. Resource name of the form projects/{project}/locations/{location}/googleApiSources/{google_api_source}.

Returns:

  • (::String)

    Identifier. Resource name of the form projects/{project}/locations/{location}/googleApiSources/{google_api_source}



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#organization_subscription::Google::Cloud::Eventarc::V1::GoogleApiSource::OrganizationSubscription

Returns Optional. Config to enable subscribing to events from all projects in the GoogleApiSource's org.

Note: The following fields are mutually exclusive: organization_subscription, project_subscriptions. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Eventarc::V1::GoogleApiSource::OrganizationSubscription)

    Optional. Config to enable subscribing to events from all projects in the GoogleApiSource's org.

    Note: The following fields are mutually exclusive: organization_subscription, project_subscriptions. If a field in that set is populated, all other fields in the set will automatically be cleared.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#project_subscriptions::Google::Cloud::Eventarc::V1::GoogleApiSource::ProjectSubscriptions

Returns Optional. Config to enable subscribing to all events from a list of projects.

All the projects must be in the same org as the GoogleApiSource.

Note: The following fields are mutually exclusive: project_subscriptions, organization_subscription. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Eventarc::V1::GoogleApiSource::ProjectSubscriptions)

    Optional. Config to enable subscribing to all events from a list of projects.

    All the projects must be in the same org as the GoogleApiSource.

    Note: The following fields are mutually exclusive: project_subscriptions, organization_subscription. If a field in that set is populated, all other fields in the set will automatically be cleared.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uid::String (readonly)

Returns Output only. Server assigned unique identifier for the channel. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted.

Returns:

  • (::String)

    Output only. Server assigned unique identifier for the channel. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The last-modified time.

Returns:



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 84

class GoogleApiSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Config to enable subscribing to all events from a list of projects.
  # @!attribute [rw] list
  #   @return [::Array<::String>]
  #     Required. A list of projects to receive events from.
  #
  #     All the projects must be in the same org. The listed projects should have
  #     the format project/\\{identifier} where identifier can be either the
  #     project id for project number. A single list may contain both formats. At
  #     most 100 projects can be listed.
  class ProjectSubscriptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Config to enabled subscribing to events from other projects in the org.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Required. Enable org level subscription.
  class OrganizationSubscription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end