Class: Google::Cloud::Eventarc::V1::GoogleApiSource::ProjectSubscriptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/eventarc/v1/google_api_source.rb

Overview

Config to enable subscribing to all events from a list of projects.

Instance Attribute Summary collapse

Instance Attribute Details

#list::Array<::String>

Returns Required. A list of projects to receive events from.

All the projects must be in the same org. The listed projects should have the format project/{identifier} where identifier can be either the project id for project number. A single list may contain both formats. At most 100 projects can be listed.

Returns:

  • (::Array<::String>)

    Required. A list of projects to receive events from.

    All the projects must be in the same org. The listed projects should have the format project/{identifier} where identifier can be either the project id for project number. A single list may contain both formats. At most 100 projects can be listed.



97
98
99
100
# File 'proto_docs/google/cloud/eventarc/v1/google_api_source.rb', line 97

class ProjectSubscriptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end