Class: Google::Cloud::Eventarc::V1::Trigger
- Inherits:
-
Object
- Object
- Google::Cloud::Eventarc::V1::Trigger
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/eventarc/v1/trigger.rb
Overview
A representation of the trigger resource.
Defined Under Namespace
Classes: ConditionsEntry, LabelsEntry, RetryPolicy
Instance Attribute Summary collapse
-
#channel ⇒ ::String
Optional.
-
#conditions ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Eventarc::V1::StateCondition}
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#destination ⇒ ::Google::Cloud::Eventarc::V1::Destination
Required.
-
#etag ⇒ ::String
readonly
Output only.
-
#event_data_content_type ⇒ ::String
Optional.
-
#event_filters ⇒ ::Array<::Google::Cloud::Eventarc::V1::EventFilter>
Required.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Required.
-
#retry_policy ⇒ ::Google::Cloud::Eventarc::V1::Trigger::RetryPolicy
Optional.
-
#satisfies_pzs ⇒ ::Boolean
readonly
Output only.
-
#service_account ⇒ ::String
Optional.
-
#transport ⇒ ::Google::Cloud::Eventarc::V1::Transport
Optional.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#channel ⇒ ::String
Returns Optional. The name of the channel associated with the trigger in
projects/{project}/locations/{location}/channels/{channel} format.
You must provide a channel to receive events from Eventarc SaaS partners.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#conditions ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Eventarc::V1::StateCondition} (readonly)
Returns Output only. The reason(s) why a trigger is in FAILED state.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The creation time.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#destination ⇒ ::Google::Cloud::Eventarc::V1::Destination
Returns Required. Destination specifies where the events should be sent to.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String (readonly)
Returns Output only. This checksum is computed by the server based on the value of other fields, and might be sent only on create requests to ensure that the client has an up-to-date value before proceeding.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#event_data_content_type ⇒ ::String
Returns Optional. EventDataContentType specifies the type of payload in MIME
format that is expected from the CloudEvent data field. This is set to
application/json if the value is not defined.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#event_filters ⇒ ::Array<::Google::Cloud::Eventarc::V1::EventFilter>
Returns Required. Unordered list. The list of filters that applies to event attributes. Only events that match all the provided filters are sent to the destination.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. User labels attached to the triggers that can be used to group resources.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The resource name of the trigger. Must be unique within the
location of the project and must be in
projects/{project}/locations/{location}/triggers/{trigger} format.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#retry_policy ⇒ ::Google::Cloud::Eventarc::V1::Trigger::RetryPolicy
Returns Optional. The retry policy to use in the Trigger.
If unset, event delivery will be retried for up to 24 hours by default: https://cloud.google.com/eventarc/docs/retry-events.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#satisfies_pzs ⇒ ::Boolean (readonly)
Returns Output only. Whether or not this Trigger satisfies the requirements of physical zone separation.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#service_account ⇒ ::String
Returns Optional. The IAM service account email associated with the trigger. The service account represents the identity of the trigger.
The iam.serviceAccounts.actAs permission must be granted on the service
account to allow a principal to impersonate the service account. For more
information, see the
Roles and permissions page specific
to the trigger destination.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#transport ⇒ ::Google::Cloud::Eventarc::V1::Transport
Returns Optional. To deliver messages, Eventarc might use other Google Cloud products as a transport intermediary. This field contains a reference to that transport intermediary. This information can be used for debugging purposes.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uid ⇒ ::String (readonly)
Returns Output only. Server-assigned unique identifier for the trigger. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last-modified time.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 97 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The retry policy configuration for the Trigger. # # Can only be set with Cloud Run destinations. # @!attribute [rw] max_attempts # @return [::Integer] # Optional. The maximum number of delivery attempts for any message. The # only valid value is 1. class RetryPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::V1::StateCondition] class ConditionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |