Class: Google::Cloud::Eventarc::V1::Trigger::RetryPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/eventarc/v1/trigger.rb

Overview

The retry policy configuration for the Trigger.

Can only be set with Cloud Run destinations.

Instance Attribute Summary collapse

Instance Attribute Details

#max_attempts::Integer

Returns Optional. The maximum number of delivery attempts for any message. The only valid value is 1.

Returns:

  • (::Integer)

    Optional. The maximum number of delivery attempts for any message. The only valid value is 1.



108
109
110
111
# File 'proto_docs/google/cloud/eventarc/v1/trigger.rb', line 108

class RetryPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end